#!perl

BEGIN
{
    unless ($ENV{AUTHOR_TESTING})
    {
        require Test::More;
        Test::More::plan(
            skip_all => 'these tests are for testing by the author');
    }
}

use strict;
use warnings;

use Test::More;
use English qw(-no_match_vars);

eval "use Test::Perl::Critic";
plan skip_all => 'Test::Perl::Critic required to criticise code' if $@;
Test::Perl::Critic->import(-profile => "xt/perlcritic.rc")
    if -e "xt/perlcritic.rc";
all_critic_ok();
